@@ -7,6 +7,7 @@
 #   Revision 0:  July 18, 2006 by Tim Edwards
 #   Revision 1:  July 24, 2006 by Jan Sundermeyer  
 #   Revision 2:  July 30, 2006 by Jan Sundermeyer
+#   Revision 3:  July 31, 2006 by Jan Sundermeyer
 #------------------------------------------------------------------------
 
 # "Standard" scaling:  converts a typical factors-of-10 coordinate system
@@ -199,7 +200,6 @@ proc parse_geometry {elemtype elemdata} {
       name -
       stringDisplay {
          # Parse various kinds of strings used by Cadence
-
 	 set dstring [lindex $elemdata 0]
 	 if {[lindex $dstring 0]== "array"} {
 	    set dstring [subst_name [lindex $dstring 1]]
@@ -212,7 +212,6 @@ proc parse_geometry {elemtype elemdata} {
 	    set oval [dec_to_oct $code]
 	    regsub -- {%[0-9]+%} $dstring [subst "$oval"] dstring
 	 }
-	 
 	 set handle {}
          if {[string first "cds" $dstring] == 0} {
 	    switch -glob $dstring {
@@ -229,7 +228,7 @@ proc parse_geometry {elemtype elemdata} {
 	    }
 	    set cds 1
 	 } else {
-	 	set cds 0
+     	    set cds 0
 	 }
          foreach dparams [lrange $elemdata 1 end] {
  	 if {$cds == 0} { 
@@ -340,9 +339,12 @@ proc parse_net {netdata} {
       if {[lindex $netString 0] == "name"} {
 	 parse_geometry [lindex $netString 0] [lrange $netString 1 end]
       } elseif {[lindex $netString 0] == "rename"} {
-      	 parse_geometry [lindex $netString 0] [lrange $netString 1 end]      
+		set elemdata [lrange $netString 1 end]
+		if { [llength [lindex $elemdata 1]]>1 } {
+			parse_geometry [lindex [lindex $elemdata 1] 0] [lrange [lindex $elemdata 1] 1 end]
+		}
       } elseif {[lindex $netString 0] == "array"} {
-	 parse_geometry [lindex $netString 0] [lrange $netString 1 end]      
+	 parse_net [list [lindex $netString 1]]
       } else {
 	 puts "Unknown net name $netString"
 	 return
@@ -487,7 +489,14 @@ proc parse_port {labellist portdata} {
 	    break
 	 }
       }
+   } else {
+   	if {$plabel == {}} {
+   	  quiet_deselect
+   	  set plabel [label make normal $portName {0 0}]
+	}
    }
+   
+   
    if {$plabel == {}} {
       puts "Can't determine port name in $portdata"
       return
