@@ -555,7 +555,19 @@ proc xcircuit::promptmakesymbol {{name ""}} {
           wm withdraw .dialog}
   .dialog.textent.title.field configure -text "Confirm symbol name:"
   .dialog.textent.txt delete 0 end
-  .dialog.textent.txt insert 0 $name
+  # Prepend technology to name, if technology is set
+  if {![catch {set techprefix $XCOps(technology)}]} {
+     if {[string match $techprefix {}]} {
+	set techprefix ""
+     } elseif {[string match $techprefix (user)]} {
+	set techprefix "::"
+     } else {
+	set techprefix [join [list $techprefix ::] ""]
+     }
+  } else {
+     set techprefix ""
+  }
+  .dialog.textent.txt insert 0 ${techprefix}${name}
   xcircuit::popupdialog
   xcircuit::addliblist .dialog "Place in: "
   xcircuit::addpinarranger .dialog
