@@ -184,7 +184,7 @@ short pagelinks(int page)
 short *pagetotals(int page, short mode)
 {
    int i;
-   short *counts, *icount, *result;
+   short *counts, *icount; /* , *result; (jdk) */
 
    if (xobjs.pagelist[page]->pageinst == NULL) return NULL;
 
@@ -879,7 +879,7 @@ void composelib(short mode)
 
       if (fval < fontcount) {
 	 stringpart *strptr;
-	 char *locobjname;
+	 /* char *locobjname; (jdk) */
 
 	 NEW_LABEL(drawname, libpage);
          libpage->parts++;
@@ -1036,7 +1036,7 @@ void catdelete()
 {
    short *newselect, *libpobjs;
    int i;
-   genericptr *testobj, *tobj;
+   /* genericptr *testobj, *tobj; (jdk) */
    objinstptr libobj;
    liblistptr ilist, llist;
    objectptr *libpage, *compobj, *tlib, *slib;
@@ -1173,7 +1173,7 @@ void linkedlistswap(liblistptr *spec, int o1, int o2)
 
 void linkedlistinsertafter(liblistptr *spec, int o1, int o2)
 {
-   liblistptr s1, s1m, s2, s2m, stmp;
+  liblistptr s1, s1m, s2; /* , s2m, stmp; (jdk) */
    int j;
 
    if ((o1 == o2) || (o1 == (o2 + 1))) return;
@@ -1246,7 +1246,7 @@ void tech_mark_changed(TechPtr ns)
 
 void catmove(int x, int y)
 {
-   int i, j, k, s1, s2, ocentx, ocenty, rangex, rangey, l;
+  int i, j, k, s1, s2, ocentx, ocenty, rangey, l; /* rangex, (jdk) */
    liblistptr spec;
    objinstptr exchobj, lobj;
 
