@@ -635,7 +635,7 @@ void togglegrid(u_short type)
       "decimal inches",
       "fractional inches",
       "centimeters",
-      "internal units",
+      "internal units", NULL      /* (jdk) */
    };
 
    /* Note that Tcl_SetVar() doesn't require double-quotes around the	*/
@@ -742,11 +742,11 @@ void newpagemenu(xcWidget w, pointertype value, caddr_t nulldata)
 
 int createlibrary(Boolean force)
 {
-   xcWidget libmenu, newbutton, oldbutton;
+  /* xcWidget libmenu, newbutton, oldbutton; (jdk) */
 #ifndef TCL_WRAPPER
    Arg wargs[2];
 #endif
-   char libstring[20];
+   /* char libstring[20]; (jdk) */
    int libnum;
    objectptr newlibobj;
 
@@ -790,8 +790,8 @@ int createlibrary(Boolean force)
 
 void makepagebutton()
 {
-   xcWidget pagemenu, newbutton;
-   char pagestring[10];
+  /* xcWidget pagemenu, newbutton; (jdk) */
+  /* char pagestring[10]; (jdk) */
 
    /* make new entry in the menu */
 
@@ -908,7 +908,7 @@ void setallstylemarks(u_short styleval)
    int fillfactor;
    const char *bptr;
 
-   const char *borders[] = {"solid", "unbordered", "dashed", "dotted"};
+   const char *borders[] = {"solid", "unbordered", "dashed", "dotted", NULL}; /* (jdk) */
    enum BorderIdx { SolidIdx, UnborderedIdx, DashedIdx, DottedIdx };
 
    objv[0] = Tcl_NewStringObj("fill", 4);
@@ -1278,7 +1278,7 @@ void stringparam(xcWidget w, caddr_t clientdata, caddr_t calldata)
 
 void startparam(xcWidget w, pointertype value, caddr_t calldata)
 {
-   genericptr *settext;
+  /* genericptr *settext; (jdk) */
 
    if (value == (pointertype)P_SUBSTRING) {
       strcpy(_STR2, (calldata != NULL) ? (char *)calldata : "substring");
