@@ -28,9 +28,9 @@ extern void redo_call(xcWidget, caddr_t, caddr_t);
 /* from tclxcircuit.c */
 
 #ifdef TCL_WRAPPER
-extern Tk_EventProc *xctk_drag(ClientData, XEvent *);
-extern Tk_EventProc *xctk_draglscroll(ClientData, XEvent *);
-extern Tk_EventProc *xctk_dragfilebox(ClientData, XEvent *);
+extern void xctk_drag(ClientData, XEvent *);
+extern void xctk_draglscroll(ClientData, XEvent *);
+extern void xctk_dragfilebox(ClientData, XEvent *);
 extern void tcl_stdflush(FILE *);
 extern void tcl_printf(FILE *, const char *, ...);
 extern int XcTagCallback(Tcl_Interp *, int, Tcl_Obj *CONST objv[]);
