@@ -151,7 +151,7 @@ objectptr NameToObject(char *objname, objinstptr *ret_inst, Boolean dopages)
 int checkpagename(objectptr thispageobj)
 {
    int p, thispage;
-   char *objname = thispageobj->name;
+   /* char *objname = thispageobj->name; (jdk) */
    Boolean changed;
    Boolean update = False;
    char *clnptr = NULL;
@@ -228,7 +228,7 @@ void connectivity(xcWidget button, caddr_t clientdata, caddr_t calldata)
    int depth, lbus, netid, subnetid;
    buslist *sbus;
    pushlistptr seltop, nextptr;
-   objectptr nettop, thisobj, pschem;
+   objectptr nettop, pschem; /*  thisobj, (jdk) */
    char *snew;
    stringpart *ppin;
 
@@ -627,7 +627,7 @@ int findsubschems(int toppage, objectptr cschem, int level, short *pagelist)
 
 void collectsubschems(int toppage)
 {
-   int loctop, level = 0;
+  int loctop; /* , level = 0; (jdk) */
    objectptr cschem;
    short *pagelist, pageno;
    Pagedata *curpage;
