@@ -170,11 +170,11 @@ void addtocolorlist(xcWidget button, int cvalue)
 
 int addnewcolorentry(int ccolor)
 {
-   xcWidget colormenu, newbutton;
+  xcWidget newbutton; /* colormenu, (jdk) */
 #ifndef XC_WIN32
-   Arg wargs[2];
+  /* Arg wargs[2]; (jdk) */
 #endif
-   int i, n = 0;
+  int i; /* , n = 0; (jdk) */
 
    /* check to see if entry is already in the color list */
 
@@ -300,7 +300,7 @@ u_short getchanges(objectptr thisobj)
 
 u_short countchanges(char **promptstr)
 {
-   int slen = 1, i, j;
+  int slen = 1, i; /* , j; (jdk) */
    u_short locchanges, changes = 0, words = 1;
    objectptr thisobj;
    char *fname;
@@ -693,7 +693,7 @@ int findnearcolor(XColor *cvexact)
 int xc_getlayoutcolor(int cidx)
 {
    XColor loccolor;
-   int i, locidx;
+   int locidx; /* i, (jdk) */
 
    loccolor.pixel = cidx;
    loccolor.flags = DoRed | DoGreen | DoBlue;
@@ -822,7 +822,7 @@ int rgb_alloccolor(int red, int green, int blue)
 int rgb_alloccolor(int red, int green, int blue)
 {
    XColor newcolor;
-   int i, pixval, tableidx;
+   int pixval, tableidx; /* i, (jdk) */
 
    /* if color is not already in list, try to allocate it; if allocation */
    /* fails, grab the closest match in the colormap.			 */
